@@ -11,6 +11,22 @@ mod tests {
         assert_min("{foo;}", "{foo}");
     }
 
+    #[test]
+    fn empty_block_statement() {
+        assert_pretty("{\n}", "{}");
+        assert_pretty("{\n//todo\n}", "{\n//todo\n}");
+
+        assert_pretty(
+            "try {\n\n} catch {\n  // Pass\n}\n",
+            "try {} catch  {\n// Pass\n}",
+        );
+    }
+
+    #[test]
+    fn empty_object_lit() {
+        assert_pretty("Object.assign({\n}, a, b);", "Object.assign({}, a, b);");
+    }
+
     #[test]
     fn labeled_statement() {
         assert_min("foo: {}", "foo:{}");
@@ -78,14 +94,14 @@ mod tests {
     fn for_statement_pretty() {
         assert_pretty(
             "for (var i = 0; i < 10; i++) {}",
-            "for(var i = 0; i < 10; i++){\n}",
+            "for(var i = 0; i < 10; i++){}",
         );
-        assert_pretty("for (i = 0; i < 10; i++) {}", "for(i = 0; i < 10; i++){\n}");
-        assert_pretty("for (;;) {}", "for(;;){\n}");
-        assert_pretty("for (foo in bar){}", "for(foo in bar){\n}");
-        assert_pretty("for (let foo in bar){}", "for(let foo in bar){\n}");
-        assert_pretty("for (foo of bar){}", "for (foo of bar){\n}");
-        assert_pretty("for (let foo of bar){}", "for (let foo of bar){\n}");
+        assert_pretty("for (i = 0; i < 10; i++) {}", "for(i = 0; i < 10; i++){}");
+        assert_pretty("for (;;) {}", "for(;;){}");
+        assert_pretty("for (foo in bar){}", "for(foo in bar){}");
+        assert_pretty("for (let foo in bar){}", "for(let foo in bar){}");
+        assert_pretty("for (foo of bar){}", "for (foo of bar){}");
+        assert_pretty("for (let foo of bar){}", "for (let foo of bar){}");
     }
 
     #[test]
